==> scilab-2.5.src.tar.gz: scilab-2.5/routines/graphics/periFig.h <==
/*------------------------------------------------------------------------
    Graphic library for 2D and 3D plotting 
    Copyright (C) 1998 Chancelier Jean-Philippe
    jpc@cergrene.enpc.fr 
 --------------------------------------------------------------------------*/

/*-------------BEGIN--------------------------------------------------------
---------------------------------------------------------------------------*/

 extern void  C2F(drawarcXfig)();
 extern void  C2F(fillarcsXfig)();
 extern void  C2F(drawarcsXfig)();
 extern void  C2F(fillareaXfig)();
 extern void  C2F(drawaxisXfig)();
 extern void  C2F(clearareaXfig)();
 extern void  C2F(clearwindowXfig)();
 extern void  C2F(xclickXfig)();
 extern void  C2F(xclick_anyXfig)();
 extern void  C2F(xgetmouseXfig)();
 extern void  C2F(xendXfig)();
 extern void  C2F(fillarcXfig)();
 extern void  C2F(viderbuffXfig)();
 extern void  C2F(fillrectangleXfig)();
 extern void  C2F(scilabgcgetXfig)();
 extern void  C2F(initgraphicXfig)();
 extern void  C2F(drawpolylineXfig)();
 extern void  C2F(drawpolylinesXfig)();
 extern void  C2F(fillpolylinesXfig)();
 extern void  C2F(fillpolylineXfig)();
 extern void  C2F(drawpolymarkXfig)();
 extern void  C2F(displaynumbersXfig)();
 extern void  C2F(xpauseXfig)();
 extern void  C2F(drawrectangleXfig)();
 extern void  C2F(drawrectanglesXfig)();
 extern void  C2F(drawsegmentsXfig)();
 extern void  C2F(xselgraphicXfig)();
 extern void  C2F(scilabgcsetXfig)();
 extern void  C2F(SetDriverXfig)();
 extern void  C2F(displaystringXfig)();
 extern void  C2F(boundingboxXfig)();
 extern void  C2F(drawarrowsXfig)(); 
 extern void  C2F(loadfamilyXfig)();
 extern void  C2F(queryfamilyXfig)();
/*----------------------------------END---------------------------*/

==> scilab-3.1.1-src.tar.gz: scilab-3.1.1/routines/graphics/periFig.h <==
/*------------------------------------------------------------------------
 *    Graphic library
 *    Copyright (C) 1998-2000 Enpc/Jean-Philippe Chancelier
 *    jpc@cereve.enpc.fr 
 --------------------------------------------------------------------------*/
#ifndef __PERIFIG_H__
#define __PERIFIG_H__

 extern void  C2F(drawarcXfig)();
 extern void  C2F(fillarcsXfig)();
 extern void  C2F(drawarcsXfig)();
 extern void  C2F(fillareaXfig)();
 extern void  C2F(drawaxisXfig)();
 extern void  C2F(clearareaXfig)();
 extern void  C2F(clearwindowXfig)();
 extern void  C2F(xclickXfig)();
 extern void  C2F(xclick_anyXfig)();
 extern void  C2F(xgetmouseXfig)();
 extern void  C2F(xendXfig)();
 extern void  C2F(fillarcXfig)();
 extern void  C2F(viderbuffXfig)();
 extern void  C2F(fillrectangleXfig)();
 extern void  C2F(scilabgcgetXfig)();
 extern void  C2F(initgraphicXfig)();
 extern void  C2F(drawpolylineXfig)();
 extern void  C2F(drawpolylinesXfig)();
 extern void  C2F(fillpolylinesXfig)();
 extern void  C2F(fillpolylineXfig)();
 extern void  C2F(drawpolymarkXfig)();
 extern void  C2F(displaynumbersXfig)();
 extern void  C2F(xpauseXfig)();
 extern void  C2F(drawrectangleXfig)();
 extern void  C2F(drawrectanglesXfig)();
 extern void  C2F(drawsegmentsXfig)();
 extern void  C2F(xselgraphicXfig)();
 extern void  C2F(scilabgcsetXfig)();
 extern void  C2F(SetDriverXfig)();
 extern void  C2F(displaystringXfig)();
 extern void  C2F(boundingboxXfig)();
 extern void  C2F(drawarrowsXfig)(); 
 extern void  C2F(loadfamilyXfig)();
 extern void  C2F(queryfamilyXfig)() ;

#endif /*__PERIFIG_H__*/
